@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,11 +13,9 @@ PluginEditorConfigureBaseWidget::PluginEditorConfigureBaseWidget(QWidget *parent
 {
 }
 
-PluginEditorConfigureBaseWidget::~PluginEditorConfigureBaseWidget()
-{
-}
+PluginEditorConfigureBaseWidget::~PluginEditorConfigureBaseWidget() = default;
 
 QString PluginEditorConfigureBaseWidget::helpAnchor() const
 {
-    return QString();
+    return {};
 }
